@@ -99,7 +99,7 @@ def get_fuped_aiguiller():
 def get_customers_si(identifier=None, value=None):
     """Fetches fup-able customers in fup-service database."""
     if identifier and value:
-        sql = ("SELECT * FROM customer where {identifier}={value}")
+        sql = ("SELECT * FROM customer where {identifier}='{value}'")
     else:
         sql = ("SELECT * FROM customer")
     try:
